@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLObject.h,v 1.28.2.2 2006/07/28 00:56:30 fox Exp $                        *
+* $Id: FXGLObject.h,v 1.28 2006/01/22 17:58:03 fox Exp $                        *
 ********************************************************************************/
 #ifndef FXGLOBJECT_H
 #define FXGLOBJECT_H
@@ -35,6 +35,9 @@ class FXGLViewer;
 class FXGLObject;
 
 
+// List of objects
+typedef FXObjectListOf<FXGLObject> FXGLObjectList;
+
 /// Basic OpenGL object
 class FXAPI FXGLObject : public FXObject {
   FXDECLARE(FXGLObject)
@@ -79,12 +82,13 @@ public:
   };
 
 
-/// Explicit template specialization
-FXTEMPLATE_EXTERN template class FXAPI FXObjectListOf<FXGLObject>;
-
-
-/// List of GL objects
-typedef FXObjectListOf<FXGLObject> FXGLObjectList;
+// Suppress warning about FXGLGroup::list not being exported
+#ifdef _MSC_VER
+#if _MSC_VER >= 1200
+#pragma warning( push )
+#endif
+#pragma warning( disable : 4251 )
+#endif
 
 
 /// Group object
@@ -160,6 +164,14 @@ public:
   };
 
 
+// Restore previous warning levels
+#ifdef _MSC_VER
+#if _MSC_VER >= 1200
+#pragma warning( pop )
+#endif
+#endif
+
+
 /// OpenGL Point Object
 class FXAPI FXGLPoint : public FXGLObject {
   FXDECLARE(FXGLPoint)
