@@ -3,7 +3,7 @@
 *                         T o p l e v el   O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXObject.h,v 1.33 2005/01/22 21:55:40 fox Exp $                          *
+* $Id: FXObject.h,v 1.35 2006/01/22 17:58:06 fox Exp $                          *
 ********************************************************************************/
 #ifndef FXOBJECT_H
 #define FXOBJECT_H
@@ -67,7 +67,7 @@ public:
   FXMetaClass(const FXchar* name,FXObject *(fac)(),const FXMetaClass* base,const void* ass,FXuint nass,FXuint assz);
 
   /// Check if metaclass is subclass of some other metaclass
-  FXbool isSubClassOf(const FXMetaClass* metaclass) const;
+  bool isSubClassOf(const FXMetaClass* metaclass) const;
 
   /// Make instance of some object
   FXObject* makeInstance() const;
@@ -174,7 +174,7 @@ public:
   const FXchar* getClassName() const;
 
   /// Check if object is member of metaclass
-  FXbool isMemberOf(const FXMetaClass* metaclass) const;
+  bool isMemberOf(const FXMetaClass* metaclass) const;
 
   /// Try handle message safely
   virtual long tryHandle(FXObject* sender,FXSelector sel,void* ptr);
