@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFileList.cpp,v 1.211.2.2 2006/11/22 15:40:27 fox Exp $                     *
+* $Id: FXFileList.cpp,v 1.211 2006/01/22 17:58:25 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -378,22 +378,22 @@ long FXFileList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr){
       url=dropfiles.mid(beg,end-beg);
 
       // Source filename
-      filesrc=FXURL::decode(FXURL::fileFromURL(url));
+      filesrc=FXURL::fileFromURL(url);
 
       // Destination filename
       filedst=dropdirectory+PATHSEPSTRING+FXPath::name(filesrc);
 
       // Move, Copy, or Link as appropriate
       if(dropaction==DRAG_MOVE){
-        FXTRACE((100,"Moving file: %s to %s\n",filesrc.text(),filedst.text()));
+        FXTRACE((1,"Moving file: %s to %s\n",filesrc.text(),filedst.text()));
         if(!FXFile::moveFiles(filesrc,filedst)) getApp()->beep();
         }
       else if(dropaction==DRAG_COPY){
-        FXTRACE((100,"Copying file: %s to %s\n",filesrc.text(),filedst.text()));
+        FXTRACE((1,"Copying file: %s to %s\n",filesrc.text(),filedst.text()));
         if(!FXFile::copyFiles(filesrc,filedst)) getApp()->beep();
         }
       else if(dropaction==DRAG_LINK){
-        FXTRACE((100,"Linking file: %s to %s\n",filesrc.text(),filedst.text()));
+        FXTRACE((1,"Linking file: %s to %s\n",filesrc.text(),filedst.text()));
         if(!FXFile::symlink(filesrc,filedst)) getApp()->beep();
         }
       }
@@ -437,7 +437,7 @@ long FXFileList::onBeginDrag(FXObject* sender,FXSelector sel,void* ptr){
     for(i=0; i<getNumItems(); i++){
       if(isItemSelected(i) && getItemFilename(i)!=".." && getItemFilename(i)!="."){
         if(!dragfiles.empty()) dragfiles+="\r\n";
-        dragfiles+=FXURL::encode(FXURL::fileToURL(getItemPathname(i)));
+        dragfiles+=FXURL::fileToURL(getItemPathname(i));
         }
       }
     return 1;
