@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFont.cpp,v 1.184.2.5 2009/02/07 05:42:01 fox Exp $                         *
+* $Id: FXFont.cpp,v 1.184 2006/01/22 17:58:26 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -585,9 +585,9 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
     FcPatternAddString(pattern,FC_FOUNDRY,(const FcChar8*)wantforge.text());
     }
 
-  // Set pixel size, based on given screen res and desired point size
+  // Set point size; work this back to a 75-dpi basis
   if(wantsize!=0){
-    FcPatternAddDouble(pattern,FC_PIXEL_SIZE,(res*wantsize)/720.0);
+    FcPatternAddDouble(pattern,FC_SIZE,(res*wantsize)/750.0);
     }
 
   // Set font weight
@@ -682,9 +682,9 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
     flags=sc?(flags|FXFont::Scalable):(flags&~FXFont::Scalable);
     }
 
-  // Get pixel size and work it back to deci-points using given screen res
-  if(FcPatternGetDouble(p,FC_PIXEL_SIZE,0,&sz)==FcResultMatch){
-    actualSize=(int)((720.0*sz)/res);
+  // Get point size; work back to deci-points for FOX
+  if(FcPatternGetDouble(p,FC_SIZE,0,&sz)==FcResultMatch){
+    actualSize=(int)((750.0*sz)/res);
     }
 
   // Get charset
@@ -696,7 +696,7 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
 
   // Open font
   font=XftFontOpenPattern(DISPLAY(getApp()),p);
-  xid=(FXID)font;
+  xid=(unsigned long)p;
 
   // Destroy pattern
   FcPatternDestroy(pattern);
@@ -910,7 +910,7 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
     // Match them
     for(f=0; f<nfontnames; f++){
 
-      //FXTRACE((100,"font=%s\n",fontnames[f]));
+      //FXTRACE((1,"font=%s\n",fontnames[f]));
 
       // Break apart into fields
       strncpy(candidate,fontnames[f],sizeof(candidate));
@@ -1128,19 +1128,22 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
         font=XLoadQueryFont(DISPLAY(getApp()),xlfd);
         }
 
+      // Remember font id
+      if(font){ xid=((XFontStruct*)font)->fid; }
+
 /*
       if(font){
         for(b=0; b<((XFontStruct*)font)->n_properties; b++){
           if(((XFontStruct*)font)->properties[b].name==XA_FONT){
             char *fn=XGetAtomName(DISPLAY(getApp()),((XFontStruct*)font)->properties[b].card32);
             strncpy(candidate,fn,sizeof(candidate));
-            FXTRACE((100,"FONT = %s\n",candidate));
+            FXTRACE((1,"FONT = %s\n",candidate));
             xlfdSplit(field,candidate);
             XFree(fn);
-            FXTRACE((100,"mat  = %s\n",field[6]));
+            FXTRACE((1,"mat  = %s\n",field[6]));
             }
           else{
-            FXTRACE((100,"%d (%s) = %d\n",((XFontStruct*)font)->properties[b].name,XGetAtomName(DISPLAY(getApp()),((XFontStruct*)font)->properties[b].name),((XFontStruct*)font)->properties[b].card32));
+            FXTRACE((1,"%d (%s) = %d\n",((XFontStruct*)font)->properties[b].name,XGetAtomName(DISPLAY(getApp()),((XFontStruct*)font)->properties[b].name),((XFontStruct*)font)->properties[b].card32));
             }
           }
         }
@@ -1407,9 +1410,6 @@ void FXFont::create(){
         font=XLoadQueryFont(DISPLAY(getApp()),actualName.text());
         }
 
-      // Remember font id
-      if(font){ xid=((XFontStruct*)font)->fid; }
-
       // Uh-oh, we failed
       if(!xid){ throw FXFontException("unable to create font"); }
 
@@ -2194,7 +2194,7 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
   res=FXApp::instance()->reg().readUnsignedEntry("SETTINGS","screenres",100);
 
   // Build object set
-  objset=FcObjectSetBuild(FC_FAMILY,FC_FOUNDRY,FC_SPACING,FC_SCALABLE,FC_WIDTH,FC_WEIGHT,FC_SLANT,FC_PIXEL_SIZE,NULL);
+  objset=FcObjectSetBuild(FC_FAMILY,FC_FOUNDRY,FC_SPACING,FC_SCALABLE,FC_WIDTH,FC_SIZE,FC_WEIGHT,FC_SLANT,NULL);
   if(objset){
 
     // Create pattern object
@@ -2264,10 +2264,10 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
               if(pitch==FC_MONO || pitch==FC_CHARCELL) pitch=FXFont::Fixed;
               }
 
-            // Pixel size works for both bitmap and scalable fonts
+            // Get point size; work back to deci-points for FOX
             size=0;
-            if(FcPatternGetDouble(p,FC_PIXEL_SIZE,0,&points)==FcResultMatch){
-              size=(int)((720.0*points)/res);
+            if(FcPatternGetDouble(p,FC_SIZE,0,&points)==FcResultMatch){
+              size=(int)((750.0*points)/res);
               }
 
             // Get scalable flag
