@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGUISignal.cpp,v 1.5.2.1 2006/08/13 15:15:35 fox Exp $                      *
+* $Id: FXGUISignal.cpp,v 1.5 2006/01/22 17:58:30 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -37,9 +37,6 @@
 #ifndef WIN32
 #include <pthread.h>
 #include <semaphore.h>
-#ifdef __CYGWIN__
-#include <asm/socket.h>         /* For FIONREAD */
-#endif
 #else
 #include <process.h>
 #endif
