@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGZFileStream.cpp,v 1.5.2.2 2007/09/28 16:42:20 fox Exp $                   *
+* $Id: FXGZFileStream.cpp,v 1.5 2006/01/22 17:58:30 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -68,19 +68,17 @@ FXuval FXGZFileStream::writeBuffer(FXuval){
   FXASSERT(begptr<=rdptr);
   FXASSERT(rdptr<=wrptr);
   FXASSERT(wrptr<=endptr);
-  while(rdptr<wrptr || f==Z_FINISH || f==Z_SYNC_FLUSH){
+  while(rdptr<wrptr){
     z->stream.next_in=(Bytef*)rdptr;
     z->stream.avail_in=wrptr-rdptr;
     z->stream.next_out=z->buffer;
     z->stream.avail_out=BUFFERSIZE;
     zerror=deflate(&z->stream,f);
-//    if(zerror!=Z_OK) break;
-    if(zerror<0) break;  // break on error condition
+    if(zerror!=Z_OK) break;
     m=z->stream.next_out-z->buffer;
     n=file.writeBlock(z->buffer,m);
     if(n<m) break;
     rdptr=(FXuchar*)z->stream.next_in;
-    if(zerror==Z_STREAM_END) break;  // break from FINISH/FLUSH
     }
   if(rdptr<wrptr){memmove(begptr,rdptr,wrptr-rdptr);}
   wrptr=begptr+(wrptr-rdptr);
@@ -100,21 +98,14 @@ FXuval FXGZFileStream::readBuffer(FXuval){
   wrptr=begptr+(wrptr-rdptr);
   rdptr=begptr;
   while(wrptr<endptr){
-//    n=file.readBlock(z->buffer,BUFFERSIZE);
-//    if(n<=0) break;
-//    z->stream.next_in=z->buffer;
-//    z->stream.avail_in=n;
-    if(z->stream.avail_in<=0){  // Get more input if buffer is empty
-      n=file.readBlock(z->buffer,BUFFERSIZE);
-      if(n<0) break;
-      z->stream.next_in=z->buffer;
-      z->stream.avail_in=n;
-      }
+    n=file.readBlock(z->buffer,BUFFERSIZE);
+    if(n<=0) break;
+    z->stream.next_in=z->buffer;
+    z->stream.avail_in=n;
     z->stream.next_out=(Bytef*)wrptr;
     z->stream.avail_out=endptr-wrptr;
     zerror=inflate(&z->stream,Z_NO_FLUSH);
-//    if(zerror!=Z_OK) break;
-    if(zerror<0) break;  // break on error condition
+    if(zerror!=Z_OK) break;
     wrptr=(FXuchar*)z->stream.next_out;
     if(zerror==Z_STREAM_END) break;
     }
@@ -127,10 +118,6 @@ bool FXGZFileStream::open(const FXString& filename,FXStreamDirection save_or_loa
   if(FXFileStream::open(filename,save_or_load,size)){
     if(FXCALLOC(&z,ZBlock,1)){
       int zerror;
-      z->stream.next_in=NULL;
-      z->stream.avail_in=0;
-      z->stream.next_out=NULL;
-      z->stream.avail_out=0;
       f=Z_NO_FLUSH;
       if(save_or_load==FXStreamLoad){
         zerror=inflateInit(&z->stream);
@@ -150,16 +137,6 @@ bool FXGZFileStream::open(const FXString& filename,FXStreamDirection save_or_loa
   }
 
 
-// Flush buffer
-bool FXGZFileStream::flush(){
-  bool status;
-  int flush=f;
-  if(f!=Z_FINISH) f=Z_SYNC_FLUSH;
-  status=FXStream::flush();
-  f=flush;
-  return status;
-  }
-
 // Close file stream
 bool FXGZFileStream::close(){
   if(dir){
