@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPath.cpp,v 1.20.2.5 2008/03/10 22:06:33 fox Exp $                          *
+* $Id: FXPath.cpp,v 1.20 2006/01/22 17:58:37 fox Exp $                          *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -100,40 +100,19 @@ FXString FXPath::root(const FXString& file){
 // Note that directory("/bla/bla/") is "/bla/bla" and NOT "/bla".
 // However, directory("/bla/bla") is "/bla" as we expect!
 FXString FXPath::directory(const FXString& file){
+  register FXint n,i;
   if(!file.empty()){
-    FXString result=file;
-    FXint p=0,q=0,s;
+    i=0;
 #ifdef WIN32
-    if(ISPATHSEP(result[q])){         // UNC
-      result[p++]=PATHSEP; q++;
-      if(ISPATHSEP(result[q])){
-        result[p++]=PATHSEP;
-        while(ISPATHSEP(result[q])) q++;
-        }
-      }
-    else if(Ascii::isLetter(result[q]) && result[q+1]==':'){
-      result[p++]=result[q++]; result[p++]=':'; q++;
-      if(ISPATHSEP(result[q])){
-        result[p++]=PATHSEP;
-        while(ISPATHSEP(result[q])) q++;
-        }
-      }
-#else
-    if(ISPATHSEP(result[q])){
-      result[p++]=PATHSEP;
-      while(ISPATHSEP(result[q])) q++;
-      }
+    if(Ascii::isLetter(file[0]) && file[1]==':') i=2;
 #endif
-    s=p;
-    while(result[q]){
-      if(ISPATHSEP(result[q])){
-        result[s=p++]=PATHSEP;
-        while(ISPATHSEP(result[q])) q++;
-        continue;
-        }
-      result[p++]=result[q++];
+    if(ISPATHSEP(file[i])) i++;
+    n=i;
+    while(file[i]){
+      if(ISPATHSEP(file[i])) n=i;
+      i++;
       }
-    return result.trunc(s);
+    return FXString(file.text(),n);
     }
   return FXString::null;
   }
@@ -226,45 +205,23 @@ FXString FXPath::extension(const FXString& file){
 //  /path/aa.bb.cc  -> /path/aa.bb
 //  /path/.aa       -> /path/.aa
 FXString FXPath::stripExtension(const FXString& file){
+  register FXint f,e,n;
   if(!file.empty()){
-    FXString result=file;
-    FXint p=0,q=0,s,e;
+    n=0;
 #ifdef WIN32
-    if(ISPATHSEP(result[q])){         // UNC
-      result[p++]=PATHSEP; q++;
-      if(ISPATHSEP(result[q])){
-        result[p++]=PATHSEP;
-        while(ISPATHSEP(result[q])) q++;
-        }
-      }
-    else if(Ascii::isLetter(result[q]) && result[q+1]==':'){
-      result[p++]=result[q++]; result[p++]=':'; q++;
-      if(ISPATHSEP(result[q])){
-        result[p++]=PATHSEP;
-        while(ISPATHSEP(result[q])) q++;
-        }
-      }
-#else
-    if(ISPATHSEP(result[q])){
-      result[p++]=PATHSEP;
-      while(ISPATHSEP(result[q])) q++;
-      }
+    if(Ascii::isLetter(file[0]) && file[1]==':') n=2;
 #endif
-    s=p;
-    while(result[q]){
-      if(ISPATHSEP(result[q])){
-        result[p++]=PATHSEP; s=p;
-        while(ISPATHSEP(result[q])) q++;
-        continue;
-        }
-      result[p++]=result[q++];
+    f=n;
+    while(file[n]){
+      if(ISPATHSEP(file[n])) f=n+1;
+      n++;
       }
-    if(result[s]=='.') s++;     // Leading '.'
-    e=p;
-    while(s<p){
-      if(result[--p]=='.'){ e=p; break; }
+    if(file[f]=='.') f++;     // Leading '.'
+    e=n;
+    while(f<n){
+      if(file[--n]=='.'){ e=n; break; }
       }
-    return result.trunc(e);
+    return FXString(file.text(),e);
     }
   return FXString::null;
   }
@@ -392,67 +349,54 @@ FXString FXPath::contract(const FXString& file,const FXString& user,const FXStri
 FXString FXPath::simplify(const FXString& file){
   if(!file.empty()){
     FXString result=file;
-    register FXint p=0;
-    register FXint q=0;
-    register FXint s;
-#ifdef WIN32
+    register FXint p,q,s;
+    p=q=0;
+#ifndef WIN32
+    if(ISPATHSEP(result[q])){
+      result[p++]=PATHSEP;
+      while(ISPATHSEP(result[q])) q++;
+      }
+#else
     if(ISPATHSEP(result[q])){         // UNC
-      result[p++]=PATHSEP; q++;
+      result[p++]=PATHSEP;
+      q++;
       if(ISPATHSEP(result[q])){
         result[p++]=PATHSEP;
         while(ISPATHSEP(result[q])) q++;
         }
       }
     else if(Ascii::isLetter(result[q]) && result[q+1]==':'){
-      result[p++]=result[q++]; result[p++]=':'; q++;
+      result[p++]=result[q++];
+      result[p++]=':';
+      q++;
       if(ISPATHSEP(result[q])){
         result[p++]=PATHSEP;
         while(ISPATHSEP(result[q])) q++;
         }
       }
-#else
-    if(ISPATHSEP(result[q])){
-      result[p++]=PATHSEP;
-      while(ISPATHSEP(result[q])) q++;
-      }
 #endif
     s=p;
     while(result[q]){
       while(result[q] && !ISPATHSEP(result[q])){
         result[p++]=result[q++];
         }
+      if(2<=p && result[p-1]=='.' && ISPATHSEP(result[p-2]) && result[q]==0){
+        p-=1;
+        }
+      else if(2<=p && result[p-1]=='.' && ISPATHSEP(result[p-2]) && ISPATHSEP(result[q])){
+        p-=2;
+        }
+      else if(3<=p && result[p-1]=='.' && result[p-2]=='.' && ISPATHSEP(result[p-3]) && !(5<=p && result[p-4]=='.' && result[p-5]=='.')){
+        p-=2;
+        if(s+2<=p){
+          p-=2;
+          while(s<p && !ISPATHSEP(result[p])) p--;
+          if(p==0) result[p++]='.';
+          }
+        }
       if(ISPATHSEP(result[q])){
-        result[p++]=PATHSEP;
         while(ISPATHSEP(result[q])) q++;
-        }
-      if(2<=p && ISPATHSEP(result[p-2]) && result[p-1]=='.'){   // Case "xxx/."
-        p--;
-        if(s<p) p--;
-        }
-      else if(3<=p && ISPATHSEP(result[p-3]) && result[p-2]=='.' && ISPATHSEP(result[p-1])){    // Case "xxx/./"
-        p-=2;
-        }
-      else if(3<=p && ISPATHSEP(result[p-3]) && result[p-2]=='.' && result[p-1]=='.' && !(((6<=p && ISPATHSEP(result[p-6])) || 5==p) && result[p-5]=='.' && result[p-4]=='.')){ // Case "xxx/.."
-        p-=2;
-        if(s<p){                // Pathological case "/.." will become "/"
-          p--;
-          while(s<p && !ISPATHSEP(result[p-1])) p--;
-          if(s<p && ISPATHSEP(result[p-1])) p--;
-          if(p==0){                             // Don't allow empty path
-            result[p++]='.';
-            }
-          }
-        }
-      else if(4<=p && ISPATHSEP(result[p-4]) && result[p-3]=='.' && result[p-2]=='.' && ISPATHSEP(result[p-1]) && !(((7<=p && ISPATHSEP(result[p-7])) || 6==p) && result[p-6]=='.' && result[p-5]=='.')){       // Case "xxx/../"
-        p-=3;
-        if(s<p){                // Pathological case "/../" will become "/"
-          p--;
-          while(s<p && !ISPATHSEP(result[p-1])) p--;
-          if(p==0){                             // Don't allow empty path
-            result[p++]='.';
-            result[p++]=PATHSEP;                // Keep trailing "/" around
-            }
-          }
+        if(!ISPATHSEP(result[p-1])) result[p++]=PATHSEP;
         }
       }
     return result.trunc(p);
@@ -469,7 +413,7 @@ FXString FXPath::absolute(const FXString& file){
 #else
   if(ISPATHSEP(file[0])){
     if(ISPATHSEP(file[1])) return FXPath::simplify(file);   // UNC
-    return FXPath::simplify(FXSystem::getCurrentDrive()+file);
+    return simplify(FXSystem::getCurrentDrive()+file);
     }
   if(Ascii::isLetter(file[0]) && file[1]==':'){
     if(ISPATHSEP(file[2])) return FXPath::simplify(file);
@@ -499,90 +443,59 @@ FXString FXPath::absolute(const FXString& base,const FXString& file){
   }
 
 
-#define ISSEP(c) (((c)=='\0') || ISPATHSEP(c))
-
 // Return relative path of file to given base directory
 //
 // Examples:
 //
-//  Base       File         Result      Comment
-//  /          /a/b         /a/b        Branch point is /
-//  /p/q/r     /a/b/c       /a/b/c      Branch point is /
-//  /a/b/c     /a/b/c/d     d           Branch point is /a/b/c
-//  /a/b/c/    /a/b/c/d     d           Branch point is /a/b/c
-//  /a/b/c/d   /a/b/c       ../         Branch point is /a/b/c
-//  /a/b/c/d   /a/b/q       ../../q     Branch point is /a/b
-//  /a/b/c     /a/b/c       .           Equal
-//  /a/b/c/    /a/b/c/      .           Equal
-//  ../a/b/c   ../a/b/c/d   d           Branch point is ../a/b/c
-//  ./a        ./b          ../b        Branch point assumed to be ..
-//  a          b            ../b        Branch point assumed to be ..
+//  Base       File         Result
+//  /a/b/c     /a/b/c/d     d
+//  /a/b/c/    /a/b/c/d     d
+//  /a/b/c/d   /a/b/c       ../
+//  ../a/b/c   ../a/b/c/d   d
+//  /a/b/c/d   /a/b/q       ../../q
+//  /a/b/c     /a/b/c       .
+//  /a/b/c/    /a/b/c/      .
+//  ./a        ./b          ../b
+//  a          b            ../b
 FXString FXPath::relative(const FXString& base,const FXString& file){
-  if(!base.empty() && !FXPath::isTopDirectory(base)){
-    register FXint p=0,q=0,bp=0,bq=0;
+  register FXint p,q,b;
+  FXString result;
 
-    // Find branch point
-#ifdef WIN32
-    while(base[p] && ((Ascii::toLower(base[p])==Ascii::toLower(file[q])) || (ISPATHSEP(base[p]) && ISPATHSEP(file[q])))){
-      if(ISPATHSEP(base[p])){
-        bp=p;
-        bq=q;
-        while(0<p && ISPATHSEP(base[p+1])) p++;           // Eat multiple slashes, but not the UNC "\\" at the start
-        while(0<q && ISPATHSEP(file[q+1])) q++;
-        }
-      p++;
-      q++;
-      }
-#else
-    while(base[p] && (base[p]==file[q])){
-      if(ISPATHSEP(base[p])){
-        bp=p;
-        bq=q;
-        while(ISPATHSEP(base[p+1])) p++;                  // Eat multiple slashes
-        while(ISPATHSEP(file[q+1])) q++;
-        }
-      p++;
-      q++;
-      }
-#endif
-
-    // Common prefix except for trailing path separator
-    if((base[p]=='\0' || ISPATHSEP(base[p])) && (file[q]=='\0' || ISPATHSEP(file[q]))){
-      bp=p;
-      bq=q;
-      }
-
-    // If branch point is not root
-#ifdef WIN32
-    if(!((ISPATHSEP(base[0]) && (bp==0 || (ISPATHSEP(base[1]) && bp==1))) || (Ascii::isLetter(base[0]) && base[1]==':' && (bp==1 || (ISPATHSEP(base[2]) && bp==2))))){
-#else
-    if(!(ISPATHSEP(base[0]) && bp==0)){
-#endif
-
-      // Strip leading path character off, if any
-      while(ISPATHSEP(file[bq])) bq++;
-
-      // Non trivial
-      if(file[bq]){
-        FXString result;
-
-        // Up to branch point
-        while(base[bp]){
-          while(ISPATHSEP(base[bp])) bp++;
-          if(base[bp]){
-            result.append(".." PATHSEPSTRING);
-            while(base[bp] && !ISPATHSEP(base[bp])) bp++;
-            }
-          }
-
-        // Append tail end
-        result.append(&file[bq]);
-        return result;
-        }
-      return ".";
-      }
+  // Find branch point
+#ifndef WIN32
+  for(p=b=0; base[p] && base[p]==file[p]; p++){
+    if(ISPATHSEP(file[p])) b=p;
     }
-  return file;
+#else
+  for(p=b=0; base[p] && Ascii::toLower(base[p])==Ascii::toLower(file[p]); p++){
+    if(ISPATHSEP(file[p])) b=p;
+    }
+#endif
+
+  // Paths are equal
+  if((base[p]=='\0' || (ISPATHSEP(base[p]) && base[p+1]=='\0')) && (file[p]=='\0' || (ISPATHSEP(file[p]) && file[p+1]=='\0'))){
+    return ".";
+    }
+
+  // Directory base is prefix of file
+  if((base[p]=='\0' && ISPATHSEP(file[p])) || (file[p]=='\0' && ISPATHSEP(base[p]))){
+    b=p;
+    }
+
+  // Up to branch point
+  for(p=q=b; base[p]; p=q){
+    while(base[q] && !ISPATHSEP(base[q])) q++;
+    if(q>p) result.append(".." PATHSEPSTRING);
+    while(base[q] && ISPATHSEP(base[q])) q++;
+    }
+
+  // Strip leading path character off, if any
+  while(ISPATHSEP(file[b])) b++;
+
+  // Append tail end
+  result.append(&file[b]);
+
+  return result;
   }
 
 
@@ -592,6 +505,7 @@ FXString FXPath::relative(const FXString& file){
   }
 
 
+
 // Return path following local path separator conventions
 FXString FXPath::convert(const FXString& path){
   FXString result(path);
@@ -605,40 +519,23 @@ FXString FXPath::convert(const FXString& path){
 // Up one level, given absolute path
 FXString FXPath::upLevel(const FXString& file){
   if(!file.empty()){
-    FXString result=file;
-    FXint p=0,q=0,s;
-#ifdef WIN32
-    if(ISPATHSEP(result[q])){         // UNC
-      result[p++]=PATHSEP;
-      if(ISPATHSEP(result[++q])){
-        result[p++]=PATHSEP;
-        while(ISPATHSEP(result[q])) q++;
-        }
-      }
-    else if(Ascii::isLetter(result[q]) && result[q+1]==':'){
-      result[p++]=result[q++];
-      result[p++]=result[q++];
-      if(ISPATHSEP(result[q])){
-        result[p++]=PATHSEP;
-        while(ISPATHSEP(result[q])) q++;
-        }
-      }
+    FXint beg=0;
+    FXint end=file.length();
+#ifndef WIN32
+    if(ISPATHSEP(file[0])) beg++;
 #else
-    if(ISPATHSEP(result[q])){
-      result[p++]=PATHSEP;
-      while(ISPATHSEP(result[q])) q++;
+    if(ISPATHSEP(file[0])){
+      beg++;
+      if(ISPATHSEP(file[1])) beg++;     // UNC
+      }
+    else if(Ascii::isLetter(file[0]) && file[1]==':'){
+      beg+=2;
+      if(ISPATHSEP(file[2])) beg++;
       }
 #endif
-    s=p;
-    while(result[q]){
-      result[p++]=result[q++];
-      if(ISPATHSEP(result[q-1])){
-        while(ISPATHSEP(result[q])) q++;
-        result[p-1]=PATHSEP;
-        if(result[q]) s=p-1;
-        }
-      }
-    return result.trunc(s);
+    if(beg<end && ISPATHSEP(file[end-1])) end--;
+    while(beg<end){ --end; if(ISPATHSEP(file[end])) break; }
+    return file.left(end);
     }
   return PATHSEPSTRING;
   }
@@ -685,97 +582,70 @@ bool FXPath::isShare(const FXString& file){
 #ifndef WIN32                 // UNIX
 
 // Enquote filename to make safe for shell
-FXString FXPath::enquote(const FXString& file,bool force){
-  FXString result(file);
-  if(0<file.length()){
-    register FXint p,q,e,c;
-    p=q=e=0;
-    while(p<file.length()){
-      switch(file[p++]){
-        case '\'':              // Quote needs to be escaped to ...'\''....
-          q+=2;                 // Two if quote is not inside quotation
-          e+=2;                 // Two more if it is
-          continue;
-        case '\\':              // Back slash
-        case '!':               // Special in csh
-        case '"':
-        case '$':               // Variable substitution
-        case '&':
-        case '(':
-        case ')':
-        case ';':
-        case '<':               // Redirections, pipe
-        case '>':
-        case '|':
-        case '`':               // Command substitution
-        case '^':               // Special in sh
-        case '*':               // Wildcard characters
-        case '+':
-        case '?':
-        case '[':
-        case ']':
-        case '\t':              // White space
-        case '\n':
-        case '\v':
-        case ' ':
-          force=true;           // Force quotes
-          q++;
-          continue;
-        case '#':               // Comments
-        case '~':               // Username substitution
-          if(p==1) force=true;  // Force quotes if at beginning
-        default:                // Normal character
-          q++;
-          continue;
-        }
+FXString FXPath::enquote(const FXString& file,bool forcequotes){
+  FXString result;
+  register FXint i,c;
+  for(i=0; (c=file[i])!='\0'; i++){
+    switch(c){
+      case '\'':              // Quote needs to be escaped
+        result+="\\\'";
+        break;
+      case '\\':              // Backspace needs to be escaped, of course
+        result+="\\\\";
+        break;
+      case '#':
+      case '~':
+        if(i) goto noquote;   // Only quote if at begin of filename
+      case '!':               // Special in csh
+      case '"':
+      case '$':               // Variable substitution
+      case '&':
+      case '(':
+      case ')':
+      case ';':
+      case '<':               // Redirections, pipe
+      case '>':
+      case '|':
+      case '`':               // Command substitution
+      case '^':               // Special in sh
+      case '*':               // Wildcard characters
+      case '?':
+      case '[':
+      case ']':
+      case '\t':              // White space
+      case '\n':
+      case ' ':
+        forcequotes=true;
+      default:                // Normal characters just added
+noquote:result+=c;
+        break;
       }
-    if(force) q+=e+2;           // Each escape adds two, quoting adds two more
-    if(result.length()<q){
-      result.length(q);         // Make longer if quoted
-      p=q=0;
-      if(force) result[q++]='\'';
-      while(p<file.length()){
-        if((c=file[p++])=='\''){        // Quote needs to be escaped
-          if(force) result[q++]='\'';   // End quotation run first
-          result[q++]='\\';
-          result[q++]=c;
-          if(force) result[q++]='\'';   // Start next quotation run
-          continue;
-          }
-        result[q++]=c;
-        }
-      if(force) result[q++]='\'';
-      }
-    FXASSERT(result.length()==q);
     }
+  if(forcequotes) return "'"+result+"'";
   return result;
   }
 
 
 // Decode filename to get original again
 FXString FXPath::dequote(const FXString& file){
-  FXString result(file);
-  if(0<result.length()){
-    register FXint e=result.length();
-    register FXint b=0;
-    register FXint r=0;
-    register FXint q=0;
-
-    // Trim tail
-    while(0<e && Ascii::isSpace(result[e-1])) --e;
-
-    // Trim head
-    while(b<e && Ascii::isSpace(result[b])) ++b;
-
-    // Dequote the rest
-    while(b<e){
-      if(result[b]=='\''){ q=!q; b++; continue; }
-      if(result[b]=='\\' && result[b+1]=='\'' && !q){ b++; }
-      result[r++]=result[b++];
+  FXString result;
+  register FXint i,c;
+  i=0;
+  while((c=file[i])!='\0' && Ascii::isSpace(c)) i++;
+  if(file[i]=='\''){
+    i++;
+    while((c=file[i])!='\0' && c!='\''){
+      if(c=='\\' && file[i+1]!='\0') c=file[++i];
+      result+=c;
+      i++;
+      }
+    }
+  else{
+    while((c=file[i])!='\0' && !Ascii::isSpace(c)){
+      if(c=='\\' && file[i+1]!='\0') c=file[++i];
+      result+=c;
+      i++;
       }
-
-    // Trunc to size
-    result.trunc(r);
     }
   return result;
   }
@@ -785,96 +655,48 @@ FXString FXPath::dequote(const FXString& file){
 #else                         // WINDOWS
 
 // Enquote filename to make safe for shell
-FXString FXPath::enquote(const FXString& file,bool force){
-  FXString result(file);
-  if(0<file.length()){
-    register FXint p,q,c;
-    p=q=0;
-    while(p<file.length()){
-      switch(file[p++]){
-        case '^':               // Escape character
-        case '"':               // Quote characters
-        case '<':               // Redirection
-        case '>':               // Redirection
-        case '|':               // Command separators
-        case '&':               // Command separators
-        case ':':               // Drive letter separator
-        case '*':               // Wildcard
-        case '?':               // Wildcard
-        case '\\':              // Path separator
-        case '/':               // Alternate path separator
-          q+=2;                 // Room for escape code
-          continue;
-        case ' ':               // White space
-        case '\t':
-        case '\v':
-          force=true;
-        default:                // Normal characters
-          q++;
-          continue;
-        }
+FXString FXPath::enquote(const FXString& file,bool forcequotes){
+  FXString result;
+  register FXint i,c;
+  for(i=0; (c=file[i])!='\0'; i++){
+    switch(c){
+      case '<':               // Redirections
+      case '>':
+      case '|':
+      case '$':
+      case ':':
+      case '*':               // Wildcards
+      case '?':
+      case ' ':               // White space
+        forcequotes=true;
+      default:                // Normal characters just added
+        result+=c;
+        break;
       }
-    if(force) q+=2;             // Surround by quotes as well
-    if(result.length()<q){
-      result.length(q);         // Make longer if quoted
-      p=q=0;
-      if(force) result[q++]='\"';
-      while(p<file.length()){
-        switch(c=file[p++]){
-          case '^':             // Escape character
-          case '"':             // Quote characters
-          case '<':             // Redirection
-          case '>':             // Redirection
-          case '|':             // Command separators
-          case '&':             // Command separators
-          case ':':             // Drive letter separator
-          case '*':             // Wildcard
-          case '?':             // Wildcard
-          case '\\':            // Path separator
-          case '/':             // Alternate path separator
-            result[q++]='^';
-            result[q++]=c;
-            continue;
-          case ' ':             // White space
-          case '\t':
-          case '\v':
-          default:              // Normal characters
-            result[q++]=c;
-            continue;
-          }
-        }
-      if(force) result[q++]='\"';
-      }
-    FXASSERT(result.length()==q);
     }
+  if(forcequotes) return "\""+result+"\"";
   return result;
   }
 
 
 // Decode filename to get original again
 FXString FXPath::dequote(const FXString& file){
-  FXString result(file);
-  if(0<result.length()){
-    register FXint e=result.length();
-    register FXint b=0;
-    register FXint r=0;
-    register FXint q=0;
-
-    // Trim tail
-    while(0<e && Ascii::isSpace(result[e-1])) --e;
-
-    // Trim head
-    while(b<e && Ascii::isSpace(result[b])) ++b;
-
-    // Dequote the rest
-    while(b<e){
-      if(result[b]=='\"'){ q=!q; b++; continue; }
-      if(result[b]=='^' && b+1<e){ b++; }
-      result[r++]=result[b++];
+  register FXint i,c;
+  FXString result;
+  i=0;
+  while((c=file[i])!='\0' && Ascii::isSpace(c)) i++;
+  if(file[i]=='"'){
+    i++;
+    while((c=file[i])!='\0' && c!='"'){
+      result+=c;
+      i++;
+      }
+    }
+  else{
+    while((c=file[i])!='\0' && !Ascii::isSpace(c)){
+      result+=c;
+      i++;
       }
-
-    // Trunc to size
-    result.trunc(r);
     }
   return result;
   }
