@@ -19,12 +19,11 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPopup.cpp,v 1.91.2.4 2007/03/08 01:51:52 fox Exp $                         *
+* $Id: FXPopup.cpp,v 1.91.2.1 2006/04/05 18:56:22 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
-#include "fxpriv.h"
 #include "fxkeys.h"
 #include "FXHash.h"
 #include "FXThread.h"
@@ -682,28 +681,38 @@ void FXPopup::popup(FXWindow* grabto,FXint x,FXint y,FXint w,FXint h){
   rh=getRoot()->getHeight();
 #else
   RECT rect;
-  MYMONITORINFO minfo;
-  HANDLE monitor;
+#if (WINVER >= 0x500) || ((defined _WIN32_WINDOWS) && (_WIN32_WINDOWS >= 0x410))
+  HINSTANCE user32;
+  typedef BOOL (WINAPI* PFN_GETMONITORINFOA)(HMONITOR, LPMONITORINFO);
+  typedef HMONITOR (WINAPI* PFN_MONITORFROMRECTA)(LPRECT, DWORD);
+  PFN_GETMONITORINFOA GetMonitorInfoA;
+  PFN_MONITORFROMRECTA MonitorFromRectA;
 
-  rect.left=x;
-  rect.right=x+w;
-  rect.top=y;
-  rect.bottom=y+h;
-
-  // Get monitor info if we have this API
-  monitor=fxMonitorFromRect(&rect,MONITOR_DEFAULTTOPRIMARY);
-  if(monitor){
+  // Suggested by "Daniel Gehriger" <gehriger@linkcad.com>
+  // The API does not exist on older Windows NT and 95, so
+  // We can't even link it, let alone call it.
+  // The solution is to ask the DLL if the function exists.
+  // And another patch from Lothar Scholtz; now it works!
+  if((user32=LoadLibraryA("User32")) && (GetMonitorInfoA=reinterpret_cast<PFN_GETMONITORINFOA>(GetProcAddress(user32,"GetMonitorInfoA"))) && (MonitorFromRectA=reinterpret_cast<PFN_MONITORFROMRECTA>(GetProcAddress(user32,"MonitorFromRect")))){
+    MONITORINFOEXA minfo;
+    HMONITOR hMon;
+    rect.left=x;
+    rect.right=x+w;
+    rect.top=y;
+    rect.bottom=y+h;
+    hMon=MonitorFromRectA(&rect,MONITOR_DEFAULTTOPRIMARY);
     memset(&minfo,0,sizeof(minfo));
     minfo.cbSize=sizeof(minfo);
-    fxGetMonitorInfo(monitor,&minfo);
+    GetMonitorInfoA(hMon,&minfo);
     rx=minfo.rcWork.left;
     ry=minfo.rcWork.top;
     rw=minfo.rcWork.right-minfo.rcWork.left;
     rh=minfo.rcWork.bottom-minfo.rcWork.top;
     }
-
-  // Otherwise use the work-area
-  else{
+  else
+#endif
+    {
+    // On Win95 and WinNT, we have to use the following
     SystemParametersInfo(SPI_GETWORKAREA,sizeof(RECT),&rect,0);
     rx=rect.left;
     ry=rect.top;
@@ -735,7 +744,6 @@ void FXPopup::popdown(){
   grabowner=NULL;
   killFocus();
   hide();
-  getApp()->flush(true);
   }
 
 
