@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXString.cpp,v 1.218.2.1 2006/08/15 05:03:16 fox Exp $                       *
+* $Id: FXString.cpp,v 1.218 2006/01/22 17:58:42 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -166,7 +166,7 @@ FXint wcvalidate(const FXnchar *string,FXint pos){
 
 // Advance to next utf8 character start
 FXint wcinc(const FXchar* string,FXint pos){
-  return (string[pos++]==0 || FXISUTF(string[pos]) || string[pos++]==0 || FXISUTF(string[pos]) || string[pos++]==0 || FXISUTF(string[pos]) || string[pos++]==0 || FXISUTF(string[pos]) || string[pos++]==0 || FXISUTF(string[pos]) || ++pos), pos;
+  return (FXISUTF(string[++pos]) || FXISUTF(string[++pos]) || FXISUTF(string[++pos]) || FXISUTF(string[++pos]) || FXISUTF(string[++pos]) || ++pos), pos;
   }
 
 
@@ -2335,48 +2335,31 @@ FXStream& operator>>(FXStream& store,FXString& s){              // Note stream f
   return store;
   }
 
-#ifdef WIN32
-#ifndef va_copy
-#define va_copy(arg,list) ((arg)=(list))
-#endif
-#endif
 
 // Print formatted string a-la vprintf
 FXString& FXString::vformat(const FXchar* fmt,va_list args){
-  FXint result=0;
+  register FXint len=0;
   if(fmt && *fmt){
-#if (_MSC_VER > 1300)                   // Have _vscprintf()
-    va_list ag;
-    va_copy(ag,args);
-    result=_vscprintf(fmt,ag);
-    va_end(ag);
-    length(result);
-    vsnprintf(str,length()+1,fmt,args);
-#elif defined(HAVE_VSNPRINTF)           // Have vsnprintf()
-#if (__GLIBC__ > 2) || ((__GLIBC__ == 2) && (__GLIBC_MINOR__ >= 1))
-    va_list ag;
-    va_copy(ag,args);
-    result=vsnprintf(str,length(),fmt,ag);
-    va_end(ag);
-    if(length()<=result){
-      length(result);
-      result=vsnprintf(str,length()+1,fmt,args);
-      }
+    register FXint n=strlen(fmt);       // Result is longer than format string
+#if defined(WIN32) || defined(HAVE_VSNPRINTF)
+//    va_list a;
+//    n+=128;                             // Add a bit of slop
+//x:  length(n);
+//    va_copy(a,args);
+//    len=vsnprintf(str,n+1,fmt,a);
+//    if(len<0){ n<<=1; goto x; }         // Some implementations return -1 if not enough room
+//    if(n<len){ n=len; goto x; }         // Others return how much space would be needed
+    n+=1024;                            // Add a lot of slop
+    length(n);                          // Some implementations return -1 if not enough room
+    len=vsnprintf(str,n+1,fmt,args);    // Others return how much space would be needed
 #else
-    va_list ag;
-x:  va_copy(ag,args);
-    result=vsnprintf(str,empty() ? 0 : length()+1,fmt,ag);
-    va_end(ag);
-    if(result<0){ length(FXMAX(64,length()*2)); goto x; }
-    if(length()<result){ length(result); goto x; }
-#endif
-#else                                   // No vsnprintf()
-    length(strlen(fmt)+1024);
-    result=vsprintf(str,fmt,args);
-    FXASSERT(0<=result && result<=length());
+    n+=1024;                            // Add a lot of slop
+    length(n);
+    len=vsprintf(str,fmt,args);
 #endif
+    FXASSERT(0<=len && len<=n);
     }
-  length(result);
+  length(len);
   return *this;
   }
 
@@ -2559,6 +2542,19 @@ FXdouble FXDoubleVal(const FXString& s){
   return strtod(s.str,NULL);
   }
 
+#if 0
+bool FXIsLongVal(const FXString &,const FXint base)
+  FXchar *end=s.str;
+  strtoll(s.str,&end,base);
+  return (s.str!=end);
+  }
+
+bool FXIsDouble(const FXString &,const FXint base)
+  FXchar *end=s.str;
+  strtod(s.str,&end,base);
+  return (s.str!=end);
+  }
+#endif
 
 // Return utf8 from ascii containing unicode escapes
 FXString fromAscii(const FXString& s){
