@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTextField.cpp,v 1.171.2.1 2006/07/14 14:54:21 fox Exp $                    *
+* $Id: FXTextField.cpp,v 1.171 2006/01/22 17:58:47 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -888,20 +888,9 @@ void FXTextField::drawCursor(FXuint state){
         dc.fillRectangle(xx-2,border,5,height-(border<<1));
 
         // Draw two characters before and after cursor
-        cl=ch=cursor;
-        if(0<cl){
-          cl=contents.dec(cl);
-          if(0<cl){
-            cl=contents.dec(cl);
-            }
-          }
-        if(ch<contents.length()){
-          ch=contents.inc(ch);
-          if(ch<contents.length()){
-            ch=contents.inc(ch);
-            }
-          }
-        drawTextRange(dc,cl,ch);
+        cl=contents.dec(contents.dec(cursor));
+        ch=contents.inc(contents.inc(cursor));
+        drawTextRange(dc,FXMAX(cl,0),FXMIN(ch,contents.length()));
         }
       }
     flags^=FLAG_CARET;
@@ -1091,7 +1080,7 @@ void FXTextField::drawPWDTextFragment(FXDCWindow& dc,FXint x,FXint y,FXint fm,FX
 
 // Draw range of text
 void FXTextField::drawTextRange(FXDCWindow& dc,FXint fm,FXint to){
-  register FXint sx,ex,xx,yy,cw,hh,ww,si,ei,lx,rx,t;
+  register FXint sx,ex,xx,yy,cw,hh,ww,si,ei,lx,rx;
   register FXint rr=width-border-padright;
   register FXint ll=border+padleft;
   register FXint mm=(ll+rr)/2;
@@ -1222,18 +1211,16 @@ void FXTextField::drawTextRange(FXDCWindow& dc,FXint fm,FXint to){
     lx=xx+font->getTextWidth(&contents[0],fm);
     rx=lx+font->getTextWidth(&contents[fm],to-fm);
     while(fm<to){
-      t=contents.inc(fm);
-      cw=font->getTextWidth(&contents[fm],t-fm);
+      cw=font->getTextWidth(&contents[fm],1);
       if(lx+cw>=0) break;
       lx+=cw;
-      fm=t;
+      fm=contents.inc(fm);
       }
     while(fm<to){
-      t=contents.dec(to);
-      cw=font->getTextWidth(&contents[t],to-t);
+      cw=font->getTextWidth(&contents[to-1],1);
       if(rx-cw<width) break;
       rx-=cw;
-      to=t;
+      to=contents.dec(to);
       }
 
     // Adjust selected range
