@@ -19,26 +19,18 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXThread.cpp,v 1.53.2.12 2008/06/18 20:03:46 fox Exp $                   *
+* $Id: FXThread.cpp,v 1.53.2.1 2006/03/28 12:56:24 fox Exp $                        *
 ********************************************************************************/
-#ifdef WIN32
-#if _WIN32_WINNT < 0x0400
-#define _WIN32_WINNT 0x0400
-#endif
-#endif
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
 #include "FXThread.h"
+
 #ifndef WIN32
-#ifdef __APPLE__
-#ifdef Status
-#undef Status
-#endif
-#ifdef KeyClass
-#undef KeyClass
-#endif
-#include <CoreServices/CoreServices.h>
+#ifdef APPLE
+#include <mach/mach_init.h>
+#include <mach/semaphore.h>
+#include <mach/task.h>
 #include <pthread.h>
 #else
 #include <pthread.h>
@@ -129,11 +121,9 @@ void FXMutex::unlock(){
 
 // Test if locked
 FXbool FXMutex::locked(){
-  if(pthread_mutex_trylock((pthread_mutex_t*)data)==0){
-    pthread_mutex_unlock((pthread_mutex_t*)data);
-    return false;
-    }
-  return true;
+  if(pthread_mutex_trylock((pthread_mutex_t*)data)==EBUSY) return TRUE;
+  pthread_mutex_unlock((pthread_mutex_t*)data);
+  return FALSE;
   }
 
 
@@ -146,7 +136,7 @@ FXMutex::~FXMutex(){
 /*******************************************************************************/
 
 
-#ifdef __APPLE__
+#ifdef APPLE
 
 
 // Initialize semaphore
@@ -156,7 +146,7 @@ FXSemaphore::FXSemaphore(FXint initial){
   // machine and mail it to: jeroen@fox-toolkit.org!!
   //FXTRACE((150,"sizeof(MPSemaphoreID*)=%d\n",sizeof(MPSemaphoreID*)));
   FXASSERT(sizeof(data)>=sizeof(MPSemaphoreID*));
-  MPCreateSemaphore(2147483647,initial,(MPSemaphoreID*)data);
+  MPCreateSemaphore(2147483647,0,(MPSemaphoreID*)data);
   }
 
 
@@ -249,7 +239,7 @@ void FXCondition::broadcast(){
 
 // Wait for condition indefinitely
 void FXCondition::wait(FXMutex& mtx){
-  pthread_cond_wait((pthread_cond_t*)data,(pthread_mutex_t*)mtx.data);
+  pthread_cond_wait((pthread_cond_t*)data,(pthread_mutex_t*)&mtx.data);
   }
 
 
@@ -259,7 +249,7 @@ FXbool FXCondition::wait(FXMutex& mtx,FXlong nsec){
   struct timespec ts;
   ts.tv_sec=nsec/1000000000;
   ts.tv_nsec=nsec%1000000000;
-x:result=pthread_cond_timedwait((pthread_cond_t*)data,(pthread_mutex_t*)mtx.data,&ts);
+x:result=pthread_cond_timedwait((pthread_cond_t*)data,(pthread_mutex_t*)&mtx.data,&ts);
   if(result==EINTR) goto x;
   return result!=ETIMEDOUT;
   }
@@ -343,9 +333,8 @@ FXbool FXThread::start(unsigned long stacksize){
 
 // Suspend calling thread until thread is done
 FXbool FXThread::join(FXint& code){
-  register pthread_t ttid=(pthread_t)tid;
   void *trc=NULL;
-  if(ttid && pthread_join(ttid,&trc)==0){
+  if(tid && pthread_join((pthread_t)tid,&trc)==0){
     code=(FXint)(FXival)trc;
     tid=0;
     return TRUE;
@@ -356,8 +345,7 @@ FXbool FXThread::join(FXint& code){
 
 // Suspend calling thread until thread is done
 FXbool FXThread::join(){
-  register pthread_t ttid=(pthread_t)tid;
-  if(ttid && pthread_join(ttid,NULL)==0){
+  if(tid && pthread_join((pthread_t)tid,NULL)==0){
     tid=0;
     return TRUE;
     }
@@ -367,9 +355,8 @@ FXbool FXThread::join(){
 
 // Cancel the thread
 FXbool FXThread::cancel(){
-  register pthread_t ttid=(pthread_t)tid;
-  if(ttid && pthread_cancel(ttid)==0){
-    pthread_join(ttid,NULL);
+  if(tid && pthread_cancel((pthread_t)tid)==0){
+    pthread_join((pthread_t)tid,NULL);
     tid=0;
     return TRUE;
     }
@@ -379,8 +366,7 @@ FXbool FXThread::cancel(){
 
 // Detach thread
 FXbool FXThread::detach(){
-  register pthread_t ttid=(pthread_t)tid;
-  return ttid && pthread_detach(ttid)==0;
+  return tid && pthread_detach((pthread_t)tid)==0;
   }
 
 
@@ -477,30 +463,29 @@ FXThreadID FXThread::current(){
 
 // Set thread priority
 void FXThread::priority(FXint prio){
-  register pthread_t ttid=(pthread_t)tid;
-  if(ttid){
-    sched_param sched={0};
-    int pcy=0;
-    pthread_getschedparam(ttid,&pcy,&sched);
+  sched_param sched={0};
+  int priomin,priomax;
+  if(tid){
+#if defined(SCHED_OTHER)
 #if defined(_POSIX_PRIORITY_SCHEDULING)
-    int priomax=sched_get_priority_max(pcy);
-    int priomin=sched_get_priority_min(pcy);
-    sched.sched_priority=FXCLAMP(priomin,prio,priomax);
+     priomax=sched_get_priority_max(SCHED_OTHER);
+     priomin=sched_get_priority_min(SCHED_OTHER);
+     sched.sched_priority=FXCLAMP(priomin,prio,priomax);
 #elif defined(PTHREAD_MINPRIORITY)
-    sched.sched_priority=FXCLAMP(PTHREAD_MIN_PRIORITY,prio,PTHREAD_MAX_PRIORITY);
+     sched.sched_priority=FXCLAMP(PTHREAD_MIN_PRIORITY,prio,PTHREAD_MAX_PRIORITY);
+#endif
+     pthread_setschedparam((pthread_t)tid,SCHED_OTHER,&sched);
 #endif
-    pthread_setschedparam(ttid,pcy,&sched);
     }
   }
 
 
 // Return thread priority
 FXint FXThread::priority(){
-  register pthread_t ttid=(pthread_t)tid;
-  if(ttid){
-    sched_param sched={0};
-    int pcy=0;
-    pthread_getschedparam(ttid,&pcy,&sched);
+  sched_param sched={0};
+  int policy;
+  if(tid){
+    pthread_getschedparam((pthread_t)tid,&policy,&sched);
     return sched.sched_priority;
     }
   return 0;
@@ -509,10 +494,7 @@ FXint FXThread::priority(){
 
 // Destroy; if it was running, stop it
 FXThread::~FXThread(){
-  register pthread_t ttid=(pthread_t)tid;
-  if(ttid){
-    pthread_cancel(ttid);
-    }
+  if(tid){ pthread_cancel((pthread_t)tid); }
   }
 
 
@@ -559,12 +541,10 @@ void FXMutex::unlock(){
 // Test if locked
 FXbool FXMutex::locked(){
 #if(_WIN32_WINNT >= 0x0400)
-  if(TryEnterCriticalSection((CRITICAL_SECTION*)data)!=0){
-    LeaveCriticalSection((CRITICAL_SECTION*)data);
-    return false;
-    }
+  if(TryEnterCriticalSection((CRITICAL_SECTION*)data)==0) return FALSE;
+  LeaveCriticalSection((CRITICAL_SECTION*)data);
 #endif
-  return true;
+  return TRUE;
   }
 
 
@@ -751,10 +731,9 @@ FXbool FXThread::start(unsigned long stacksize){
 
 // Suspend calling thread until thread is done
 FXbool FXThread::join(FXint& code){
-  register HANDLE ttid=(HANDLE)tid;
-  if(ttid && WaitForSingleObject(ttid,INFINITE)==WAIT_OBJECT_0){
-    GetExitCodeThread(ttid,(DWORD*)&code);
-    CloseHandle(ttid);
+  if(tid && WaitForSingleObject((HANDLE)tid,INFINITE)==WAIT_OBJECT_0){
+    GetExitCodeThread((HANDLE)tid,(DWORD*)&code);
+    CloseHandle((HANDLE)tid);
     tid=0;
     return TRUE;
     }
@@ -764,9 +743,8 @@ FXbool FXThread::join(FXint& code){
 
 // Suspend calling thread until thread is done
 FXbool FXThread::join(){
-  register HANDLE ttid=(HANDLE)tid;
-  if(ttid && WaitForSingleObject(ttid,INFINITE)==WAIT_OBJECT_0){
-    CloseHandle(ttid);
+  if(tid && WaitForSingleObject((HANDLE)tid,INFINITE)==WAIT_OBJECT_0){
+    CloseHandle((HANDLE)tid);
     tid=0;
     return TRUE;
     }
@@ -776,9 +754,8 @@ FXbool FXThread::join(){
 
 // Cancel the thread
 FXbool FXThread::cancel(){
-  register HANDLE ttid=(HANDLE)tid;
-  if(ttid && TerminateThread(ttid,0)){
-    CloseHandle(ttid);
+  if(tid && TerminateThread((HANDLE)tid,0)){
+    CloseHandle((HANDLE)tid);
     tid=0;
     return TRUE;
     }
@@ -845,18 +822,16 @@ FXThread* FXThread::self(){
 
 // Set thread priority
 void FXThread::priority(FXint prio){
-  register HANDLE ttid=(HANDLE)tid;
-  if(ttid){
-    SetThreadPriority(ttid,prio);
+  if(tid){
+    SetThreadPriority((HANDLE)tid,prio);
     }
   }
 
 
 // Return thread priority
 FXint FXThread::priority(){
-  register HANDLE ttid=(HANDLE)tid;
-  if(ttid){
-    return GetThreadPriority(ttid);
+  if(tid){
+    return GetThreadPriority((HANDLE)tid);
     }
   return 0;
   }
@@ -864,11 +839,7 @@ FXint FXThread::priority(){
 
 // Destroy
 FXThread::~FXThread(){
-  register HANDLE ttid=(HANDLE)tid;
-  if(ttid){
-    TerminateThread(ttid,0);
-    CloseHandle(ttid);
-    }
+  if(tid){ TerminateThread((HANDLE)tid,0); CloseHandle((HANDLE)tid); }
   }
 
 
