@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxutils.cpp,v 1.129.2.4 2008/05/20 16:21:12 fox Exp $                        *
+* $Id: fxutils.cpp,v 1.129.2.2 2006/04/02 00:59:57 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -122,10 +122,10 @@ FXbool fxisconsole(const FXchar *path){
     if(dwBytes!=IMAGE_SIZEOF_FILE_HEADER) goto x;
 
     // Read the optional header of file.
-    if(ReadFile(hImage,&optional_header,sizeof(IMAGE_OPTIONAL_HEADER),&dwBytes,NULL)==0) goto x;
+    if(ReadFile(hImage,&optional_header,IMAGE_SIZEOF_NT_OPTIONAL_HEADER,&dwBytes,NULL)==0) goto x;
 
     // Test bytes read
-    if(dwBytes!=sizeof(IMAGE_OPTIONAL_HEADER)) goto x;
+    if(dwBytes!=IMAGE_SIZEOF_NT_OPTIONAL_HEADER) goto x;
 
     // Switch on systems
     switch(optional_header.Subsystem){
@@ -164,17 +164,14 @@ FXbool fxisconsole(const FXchar*){
 void fxassert(const char* expression,const char* filename,unsigned int lineno){
 #ifndef WIN32
   fprintf(stderr,"%s:%d: FXASSERT(%s) failed.\n",filename,lineno,expression);
-  fflush(stderr);
 #else
 #ifdef _WINDOWS
   char msg[MAXMESSAGESIZE];
   sprintf(msg,"%s(%d): FXASSERT(%s) failed.\n",filename,lineno,expression);
   OutputDebugStringA(msg);
   fprintf(stderr,"%s",msg); // if a console is available
-  fflush(stderr);
 #else
   fprintf(stderr,"%s(%d): FXASSERT(%s) failed.\n",filename,lineno,expression);
-  fflush(stderr);
 #endif
 #endif
   }
@@ -186,7 +183,6 @@ void fxmessage(const char* format,...){
   va_list arguments;
   va_start(arguments,format);
   vfprintf(stderr,format,arguments);
-  fflush(stderr);
   va_end(arguments);
 #else
 #ifdef _WINDOWS
@@ -197,12 +193,10 @@ void fxmessage(const char* format,...){
   va_end(arguments);
   OutputDebugStringA(msg);
   fprintf(stderr,"%s",msg); // if a console is available
-  fflush(stderr);
 #else
   va_list arguments;
   va_start(arguments,format);
   vfprintf(stderr,format,arguments);
-  fflush(stderr);
   va_end(arguments);
 #endif
 #endif
@@ -215,7 +209,6 @@ void fxerror(const char* format,...){
   va_list arguments;
   va_start(arguments,format);
   vfprintf(stderr,format,arguments);
-  fflush(stderr);
   va_end(arguments);
   abort();
 #else
@@ -227,14 +220,12 @@ void fxerror(const char* format,...){
   va_end(arguments);
   OutputDebugStringA(msg);
   fprintf(stderr,"%s",msg); // if a console is available
-  fflush(stderr);
   MessageBoxA(NULL,msg,NULL,MB_OK|MB_ICONEXCLAMATION|MB_APPLMODAL);
   DebugBreak();
 #else
   va_list arguments;
   va_start(arguments,format);
   vfprintf(stderr,format,arguments);
-  fflush(stderr);
   va_end(arguments);
   abort();
 #endif
@@ -248,7 +239,6 @@ void fxwarning(const char* format,...){
   va_list arguments;
   va_start(arguments,format);
   vfprintf(stderr,format,arguments);
-  fflush(stderr);
   va_end(arguments);
 #else
 #ifdef _WINDOWS
@@ -259,13 +249,11 @@ void fxwarning(const char* format,...){
   va_end(arguments);
   OutputDebugStringA(msg);
   fprintf(stderr,"%s",msg); // if a console is available
-  fflush(stderr);
   MessageBoxA(NULL,msg,NULL,MB_OK|MB_ICONINFORMATION|MB_APPLMODAL);
 #else
   va_list arguments;
   va_start(arguments,format);
   vfprintf(stderr,format,arguments);
-  fflush(stderr);
   va_end(arguments);
 #endif
 #endif
@@ -279,7 +267,6 @@ void fxtrace(unsigned int level,const char* format,...){
     va_list arguments;
     va_start(arguments,format);
     vfprintf(stderr,format,arguments);
-    fflush(stderr);
     va_end(arguments);
 #else
 #ifdef _WINDOWS
@@ -287,15 +274,13 @@ void fxtrace(unsigned int level,const char* format,...){
     va_list arguments;
     va_start(arguments,format);
     vsnprintf(msg,sizeof(msg),format,arguments);
+    va_end(arguments);
     OutputDebugStringA(msg);
     fprintf(stderr,"%s",msg); // if a console is available
-    fflush(stderr);
-    va_end(arguments);
 #else
     va_list arguments;
     va_start(arguments,format);
     vfprintf(stderr,format,arguments);
-    fflush(stderr);
     va_end(arguments);
 #endif
 #endif
